#define Global_cxx
#include "single_top_analysis/AnalysisMain.hpp"
#include <iostream>
#include <string>

// histogramming classes to include
#include "single_top_analysis/EventWeight.hpp"
#include "single_top_analysis/CutNJets.hpp"
#include "single_top_analysis/HistogrammingNJets.hpp"

// and cuts to include
#include "single_top_analysis/CutBasic.hpp"

using std::cout;
using std::endl;


// Only declare main if not in CINT (not interactive?)
#ifndef __CINT__
int main(int argc, char **argv) 
#endif
{
  cout<<"<driver> Starting parton_analysis"<<endl;

  bool doFast=false;


   ///////////////////////////////////////////////////////////
   // Instantiate a chain for the root tuple(s)
   // Instantiate a chain for the top root tuple(s)
   TChain *coch = new TChain("CollectionTree");
   TChain *evch = new TChain("EV0");
   TChain *trch = new TChain("Truth0");

   // and use these to instantiate the analysis class
   AnalysisMain mystudy;
   
   //
   // parse the command line to get the 
   // input top root file and 
   // the input trigger root file
   int returnval=mystudy.ParseCmdLine(argc,argv,coch,evch,trch);
   
   if(returnval!=0) return returnval;
   
   bool doSkim=false;
   TString skimFileName;
   //
   // defaults:

   // check additional command line arguments:
   // Parse Command Line for 
   for (int i = 1; i < argc; ++i) {
     //cout<<"Command line parameter "<<i<<" is "<<argv[i]<<endl;
     //
     // check if this is the flag for an input file
     if (!strcmp(argv[i],"-skimFile")) {  // Get name of skimfile
       skimFileName=argv[i+1];
       cout<<"Driver: Setting output skim file to "<<skimFileName<<endl;
       doSkim=true;
       ++i;
     }// if doskim
     else if (!strcmp(argv[i],"-fast")) {  // run fast by only filling few histograms
       doFast=true;
       cout<<"Driver: Fast running "<<endl;
     }//elseif fast
     
   } // end of parsing for additional command line arguments

   
   Particles *obj=&mystudy;
   //////////////////////////////////////////////////////////////
   //
   // add histograms and cuts I would like to make:
   //
   // first always add the EventWeight
   mystudy.AddCut(new EventWeight(obj));

   // now we make a cut
   mystudy.AddCut(new CutNJets(obj));

   // now we can add histograms.
   mystudy.AddCut(new HistogrammingNJets(obj));

   if(!doFast) {

     // apply a cut next. The 
     
     
     // make D0-style preselection cuts
     //                    electron pt, eta; met; jet pt, eta, nmin, nmax; leading jet pt, eta
     mystudy.AddCut(new CutBasic(obj,15.,2.0,15., 15.,3.5,  2,4,        25.,2.5));

     // and make the histograms again
     mystudy.AddCut(new HistogrammingNJets(obj));
     
   } // end of: if ! do fast
  
   cout << "<driver> Starting Loop..." << endl << endl;


   // Loop over the chain already!
   mystudy.Loop();


   cout<<"<driver> Finished looping, saving output to file "<<mystudy.GetHistogramFileName()<<"!"<<endl;
   // and save the output
   mystudy.WriteHistogramFile();
   mystudy.CloseHistogramFile();

   cout<<"<driver> Deleting chains"<<endl;
   if(trch) delete trch;
   if(evch) delete evch;
   if(coch) delete coch;
   trch=0;
   evch=0;
   coch=0;

   cout<<"<driver> Done!"<<endl;
   return 0;
}
