///////////////////////////////////////////////////////////////////////////////
//
// HistoCut
// --------------
// Authors: Aran Garcia-Bellido (aran@fnal.gov),
//          Gabriella Gaudio (ggaudio@u.washington.edu)
//          Brigitte Vachon (vachon@fnal.gov)
//          Gordon Watts (gwatts@fnal.gov)
//
// Date: Oct. 01 2003
// 
// This class is an abstract class derived from the BaseCut class. Here we
// define the wrappers for TH1F, TH2F and TGraph. The actual booking and
// filling of the histograms are done in a class derived from this one. 
//
// Modifications:
// 2/27/2004, RS: adjust to use in NLO single top analysis
//
//
//
///////////////////////////////////////////////////////////////////////////////

#ifndef HistoCut_h
#define HistoCut_h


#include "single_top_analysis/BaseCut.hpp"
#include "single_top_analysis/Particles.hpp"

#include <string>
#include <vector>

#include <TObjArray.h>
#include "single_top_analysis/myTH1F.hpp"
#include "single_top_analysis/myTH2F.hpp"
//#include <TGraph.h>
#include <TDirectory.h>

using namespace std;

class HistoCut : public BaseCut
{

public:
 
  // constructor
  HistoCut(Particles* obj=0);
  
  // destructor
  ~HistoCut();

  //method
  void BookHistos(void);
  bool Apply();
  

  // helper method to Create histograms: 1-d
  inline myTH1F* DeclareTH1F(const std::string& name, const std::string& title,
			     int nXBins, Double_t xMin, Double_t xMax);
  // helper method to Create histograms: 2-d
  inline myTH2F* DeclareTH2F(const std::string& name, const std::string& title,
  			     int nXBins, Double_t xMin, Double_t xMax,
  			     int nYBins, Double_t yMin, Double_t yMax);
  // wrapper to declare a new graph
  //inline TGraph* DeclareTGraph(const Int_t& nBins);


private:
  // collection of all histograms
  TObjArray    _histograms;
  // collect graphs in this array
  TObjArray    _graphs;
 
  ClassDef (HistoCut,1);

};

// wrapper to declare a 1-d histo
//______________________________________________________________________________

myTH1F* HistoCut::DeclareTH1F(const std::string& name, const std::string& title,
			      int nXBins, Double_t xMin, Double_t xMax)
{
  myTH1F* h = new myTH1F(GetDirectory(),GetParticleObj(),name, title, nXBins, xMin, xMax);
  _histograms.Add(h);
  return h; 
}
  
// wrapper to declare a 2-d histo
//______________________________________________________________________________
myTH2F* HistoCut::DeclareTH2F(const std::string& name, const std::string& title,
			    int nXBins, Double_t xMin, Double_t xMax,
			    int nYBins, Double_t yMin, Double_t yMax)
{
  myTH2F *h=new myTH2F(GetDirectory(),GetParticleObj(),name, title, nXBins, xMin, xMax, nYBins, yMin, yMax);
  _histograms.Add(h);
  return h;
}
  
// wrapper for a TGraph
// Create it in memory and then add it to the array of graphs.
//______________________________________________________________________________

//TGraph* HistoCut::DeclareTGraph(const Int_t& nBins)
//{
//  // need to fill this in if we want to use it!
//}
  
#endif







