////////////////////////////////////////////////////////////////
//
// Purpose: Store 1-d or 2-d histograms in a directory structure
//
// Author: Reinhard Schwienhorst
//
// Date: 10/19/06
//
// Modifications:
//
/////////////////////////////////////////////////////////////////////
#include <TH2.h>
#include <TGraph.h>
#include <string>
#include <TDirectory.h>
#include <TObject.h>

class Particles;

class myTH2F: public TObject
{
 public:
  //  constructor
  myTH2F(TDirectory *baseDir,Particles *obj,const std::string& name, const std::string& title,
	 int nXBins, Double_t xMin, Double_t xMax,int nYBins, Double_t yMin, Double_t yMax);
  // destructor
  ~myTH2F() {};
  // fill method, fill only some of the histograms depending on npart
  int Fill(Double_t x,Double_t y, Double_t myWeight);
  // Fill method that fills a histogram without using any weight
  int FillWithoutWeight(Double_t x,Double_t y);
  //
  // write output to the file
  int Write(TDirectory *baseDir);
  //
  // copy the content of this histogram into another.
  int Copy(myTH2F other);
  //
  // Divide this histogram by the other.
  int Divide(myTH2F other);
  //
  // Set the label for the X axis.
  void SetXAxisTitle(const TString label);
  //
  // Set the label for the Y axis.
  void SetYAxisTitle(const TString label);
  //
  // Set the label for individual bins on the Y axis.
  void SetXAxisBinLabel(Int_t iBin,TString label);
  //
  // Set the label for individual bins on the Y axis.
  void SetYAxisBinLabel(Int_t iBin,TString label);
  //
  // Get the number of bins.
  int GetNbinsX() {return _hincl->GetNbinsX(); };

  // declare the histograms and make them public:
  TH2F* _hincl;           // make every histogram three times:

 private:
  // a pointer to the class storing objects and other stuff
  Particles *_obj;

};
