///////////////////////////////////////////////////////////////////////////////
//
// CutNJets
// --------------
//
// Authors: Reinhard Schwienhorst
//         
//
// Date: November 7, 2006
//
// Modified:
// 
//
///////////////////////////////////////////////////////////////////////////////

#include "single_top_analysis/CutNJets.hpp"
#include<iostream>

using namespace std;


//----------------
// constructor
//----------------
CutNJets::CutNJets(Particles *obj)
{
  SetParticleObj(obj);
}

//----------------
// destructor
//----------------
CutNJets::~CutNJets()
{
  
}

//----------------
// Book
//----------------
void CutNJets::BookHistos(){
  
  _hNJetsBefore = DeclareTH1F("NJetsBefore","Number of Jets before the cut",10,0.,10.);
  _hNJetsBefore->SetXAxisTitle("# of jets");
  _hNJetsAfter  = DeclareTH1F("NJetsAfter","Number of Jets after the cut",10,0.,10.);
  _hNJetsAfter ->SetXAxisTitle("# of jets");
  //cout<<"end of CutNJets::BookHistos"<<endl;
  
  // now get configuration parameters:
  Particles *obj=GetParticleObj();
  TEnv * config=obj->GetConfig();

  _nJetsMin=config->GetValue("Cut.Jet.Njets.Min",0);
  _nJetsMax=config->GetValue("Cut.Jet.Njets.Max",-1);
  
  
}

//-------------
// Apply
//-------------
bool CutNJets::Apply()
{
  //cout<<"Begin of CutNJets::Apply()"<<endl;
  Particles *obj=GetParticleObj();
  EventTree * evTree=obj->GetEventTree();

  // 
  
  // and fill the histograms before the cut
  _hNJetsBefore->Fill(evTree->PJet_N);

  //
  // now make the cuts:
  Bool_t eventPass=kTRUE;

  if(evTree->PJet_N < _nJetsMin) eventPass=kFALSE;

  // negative number for max means no cut:
  if(_nJetsMax>=0 && evTree->PJet_N > _nJetsMax) eventPass=kFALSE;

  // fill the histogram after the cut
  if(eventPass) _hNJetsAfter->Fill(evTree->PJet_N);
  


  //cout<<"End of CutNJets::Apply()"<<endl;
  return eventPass;  
  
}












