///////////////////////////////////////////////////////////////////////////////
//
// EventWeight
// --------------
//
// Authors: Reinhard Schwienhorst
//         
//
// Date: October 19, 2006
//
// Modified:
// 
//
///////////////////////////////////////////////////////////////////////////////

#include "single_top_analysis/EventWeight.hpp"
#include <iostream>

using namespace std;


//----------------
// constructor
//----------------
EventWeight::EventWeight(Particles *obj)
{
  SetParticleObj(obj);
}

//----------------
// destructor
//----------------
EventWeight::~EventWeight()
{
  
}

//----------------
// Book
//----------------
void EventWeight::BookHistos()
{
  Particles *obj=GetParticleObj();
  TEnv* conf=obj->GetConfig();
  //cout<<"EventWeight::BookHistos, debug level "<<obj->GetDebugLevel()<<endl;

  _hTreeWeight = DeclareTH1F("TreeWeight","Event Weight from the input tree",100,0.,10.);
  _hTreeWeight->SetXAxisTitle("tree weight");
  _hGlobalWeight = DeclareTH1F("GlobalWeight","Global Event Weight",100,0.,10.);
  _hGlobalWeight->SetXAxisTitle("global weight");
  _hOutputWeight = DeclareTH1F("OutputWeight","Output Event Weight",100,0.,10.);
  _hOutputWeight->SetXAxisTitle("output weight");

  //
  // get the global weight for this source
  TString source=obj->GetSourceName();
  TString wq="Weight.Source."+source;
  obj->SetGlobalEventWeight(conf->GetValue(wq,1.0));
  if(obj->GetDebugLevel()>1) cout<<"Global event weight for source "<<source<<" is "<<obj->GetGlobalEventWeight()<<endl;

}

//-------------
// Apply
//-------------
bool EventWeight::Apply()
{
  //cout<<"begin of cut_basic"<<endl;
  Particles *obj=GetParticleObj();

  //
  // here we create the event weight to apply to each histogram
  // for now this is simply the global event weight.
  obj->SetOutputEventWeight(obj->GetGlobalEventWeight());

  //---------------------------------------------------
  //
  // Histogramming
  //
  _hTreeWeight->FillWithoutWeight(obj->GetTreeEventWeight());
  _hGlobalWeight->FillWithoutWeight(obj->GetGlobalEventWeight());

  //
  // finally, fill the histogram of output event weights
  _hOutputWeight->FillWithoutWeight(obj->GetEventWeight());

  return true;
  
}












