////////////////////////////////////////////////////////////////
//
// wrapper class for 1d histograms
//
//
#include "single_top_analysis/myTH1F.hpp"
#include "single_top_analysis/Particles.hpp"
#include <iostream>

using namespace std;

//-----------------------------------------------------------------
// Create the same histogram in several different directories
myTH1F::myTH1F(TDirectory *baseDir,Particles *obj,const std::string& name, const std::string& title,
	       int nXBins, Double_t xMin, Double_t xMax): _obj(obj)
{
  //Create directories
  baseDir->cd();
  //
  // put in subdirectory
  //if(! baseDir->GetKey("inclusive")) baseDir->mkdir("inclusive");  
  //
  // now Create histograms and store pointers to them.
  //baseDir->cd("inclusive");
  _hincl=new TH1F(name.c_str(),title.c_str(),nXBins,xMin,xMax);  
  
}

//-----------------------------------------------------------------
// fill each of the histograms
int myTH1F::Fill(Double_t x, Double_t myWeight)
{
  //
  // the weight is given to us by the Particles class.
  Double_t weight=_obj->GetEventWeight();

  // if the input weight is greater than 0, use that instead of the 
  // global event weight
  if(myWeight>0.) weight=myWeight;

  // always fill the inclusive histogram:
  _hincl->Fill(x,weight);
  return 0;
}

//-----------------------------------------------------------------
// fill each of the histograms, but without weight
int myTH1F::FillWithoutWeight(Double_t x)
{
  // always fill the inclusive histogram:
  _hincl->Fill(x,1.);
  return 0;
}

//----------------------------------------------------------------
// write histograms to the output file
int myTH1F::Write(TDirectory *baseDir)
{
  // now Create histograms and store pointers to them.
  //baseDir->cd("inclusive");
  _hincl->Write();  
  
  return 0;
}

//----------------------------------------------------------------
// copy the content of this histogram into the other
int myTH1F::Copy(myTH1F other)
{
  // call the copy method for each histogram
  _hincl->Copy(*(other._hincl));  
  
  return 0;
}

//----------------------------------------------------------------
//divide the content of this histogram by the other
int myTH1F::Divide(myTH1F other)
{
  // call the divide method for each histogram
  _hincl->Divide(other._hincl);  
  
  return 0;
}

//----------------------------------------------------------------
// Set the labels for the X axis
void myTH1F::SetXAxisTitle(TString label)
{
  // call the method for each histogram
  _hincl->GetXaxis()->SetTitle(label);  
  
  return;
}

//----------------------------------------------------------------
// Set the labels for the X axis bins individually
void myTH1F::SetXAxisBinLabel(Int_t iBin,TString label)
{
  // call the method for each histogram
  // to Set the bin label on the X axis
  _hincl->GetXaxis()->SetBinLabel(iBin,label);  
  
  return;
}


